@@ -23,64 +23,45 @@
 #define QOF_H_
 /** @defgroup QOF Query Object Framework 
  @{
-*/
-
-/**
-    @addtogroup Date Date:  Date and Time Printing, Parsing and Manipulation
-    @ingroup QOF
-*/
-/**
-    @addtogroup Entity Entity: Types, Identity and Instance Framework
-    @ingroup QOF
-
-*/
-/**
-    @addtogroup KVP KVP: Key-Value Pairs
-    @ingroup QOF
-*/
-/**
-    @addtogroup Math128 Math128: 128-bit Integer Math Library
-    @ingroup QOF
-*/
-/**
-    @addtogroup Numeric Numeric: Rational Number Handling w/ Rounding Error Control
-    @ingroup QOF
-*/
-/**
-    @addtogroup Object Object: Dynamic Object Class Framework
-    @ingroup QOF
-*/
-/**
-    @addtogroup Query Query: Querying for Objects
-    @ingroup QOF
-*/
-/**
-    @addtogroup Trace Trace: Error Reporting and Debugging
-    @ingroup QOF
-*/
-/** @addtogroup Event Event: QOF event handlers.
+	@addtogroup Book Book:        The QOF Data Set.
 	@ingroup QOF
-*/
-/** @addtogroup Choice Choice and collect : One to many links.
-	@ingroup QOF
-*/
-/** @addtogroup BookMerge Merging QofBook structures
-	@ingroup QOF
-*/
-/** \addtogroup Reference Referring to entities outside a partial book.
-	\ingroup QOF
-*/
-/**
-    @addtogroup Utilities Misc Utilities
+    @addtogroup Object Object:    Describing data structure.
     @ingroup QOF
+    @addtogroup Class Class:      Getting and setting entity values.
+    @ingroup QOF
+    @addtogroup QOFTIME Time:     64bit UTC Time handling.
+    @ingroup QOF
+    @addtogroup Numeric Numeric:  Rational Number Handling with Rounding Error Control
+    @ingroup QOF
+    @addtogroup KVP KVP:          Key-Value Pairs
+    @ingroup QOF
+	@addtogroup Backend Backends: Permanent storage for QOF entities.
+	@ingroup QOF
+    @addtogroup Query Query:      Querying for Objects
+    @ingroup QOF
+    @addtogroup Trace Trace:      Error Reporting and Debugging
+    @ingroup QOF
+    @addtogroup Event Event:      QOF event handlers.
+    @ingroup QOF
+    @addtogroup Choice Choice:    One to many links.
+    @ingroup QOF
+    @addtogroup BookMerge Merge:  Merging QofBook structures
+    @ingroup QOF
+    @addtogroup Reference Reference: Referring to entities outside a partial book.
+    @ingroup QOF
+    @addtogroup UNDO Undo:        Track and undo or redo entity changes
+    @ingroup QOF
+    @addtogroup Utilities Utilities: Miscellany
+    @ingroup QOF
+@}
 */
-/** @} */
 
 #include <glib.h>
 #include "qofid.h"
 #include "qoflog.h"
-#include "gnc-date.h"
-#include "gnc-numeric.h"
+#include "qofdate.h"
+#include "qoftime.h"
+#include "qofnumeric.h"
 #include "qofutil.h"
 #include "guid.h"
 #include "kvp_frame.h"
@@ -101,6 +82,7 @@
 #include "qofbookmerge.h"
 #include "qofreference.h"
 #include "qofla-dir.h"
+#include "qofundo.h"
 #include "deprecated.h"
 
 /** allow easy logging of QSF debug messages */
