@@ -22,7 +22,6 @@
 /** @addtogroup Object
     @{ */
 /** @addtogroup Object_Private
-    Private interfaces, not meant to be used by applications.
     @{ */
 /** @name  Backend_Private
    Pseudo-object defining how the engine can interact with different
@@ -240,158 +239,139 @@
 
 struct QofBackendProvider_s
 {
-  /** Some arbitrary name given for this particular backend provider */
-  const char * provider_name;
+/** Some arbitrary name given for this particular backend provider */
+	const gchar *provider_name;
 
-  /** The access method that this provider provides, for example,
-   *  file:// http:// postgres:// or sqlite://, but without the :// at the end
-   */
-  const char * access_method;
+/** The access method that this provider provides, for example,
+file:// http:// postgres:// or sqlite://, but without
+the :// at the end
+*/
+	const gchar *access_method;
 
-  /** \brief Partial QofBook handler
-	
-	TRUE if the backend handles external references
-	to entities outside this book and can save a QofBook that
-	does not contain any specific QOF objects.
-	*/
-  gboolean partial_book_supported;
-	
-  /** Return a new, fully initialized backend. 
-   *
-   * If the backend supports configuration, all configuration options
-   * should be initialised to usable values here.
-   * */
-  QofBackend * (*backend_new) (void);
+/** \brief Partial QofBook handler
+
+TRUE if the backend handles external references
+to entities outside this book and can save a QofBook that
+does not contain any specific QOF objects. */
+	gboolean partial_book_supported;
+
+/** Return a new, fully initialized backend. 
+
+If the backend supports configuration, all configuration options
+should be initialised to usable values here. */
+	QofBackend *(*backend_new) (void);
 
 /** \brief Distinguish two providers with same access method.
   
-  More than 1 backend can be registered under the same access_method,
-  so each one is passed the path to the data (e.g. a file) and
-  should return TRUE only:
--# if the backend recognises the type as one that it can load and write or 
+More than 1 backend can be registered under the same access_method,
+so each one is passed the path to the data (e.g. a file) and
+should return TRUE only:
+-# if the backend recognises the type as one that it can load and
+write or 
 -# if the path contains no data but can be used (e.g. a new session).
   
-  \note If the backend can cope with more than one type, the backend
-  should not try to store or cache the sub-type for this data.
-  It is sufficient only to return TRUE if any ONE of the supported
-  types match the incoming data. The backend should not assume that
-  returning TRUE will mean that the data will naturally follow.
-  */
-  gboolean (*check_data_type) (const char*);
-  
-  /** Free this structure, unregister this backend handler. */
-  void (*provider_free) (QofBackendProvider *);
+\note If the backend can cope with more than one type, the backend
+should not try to store or cache the sub-type for this data.
+It is sufficient only to return TRUE if any ONE of the supported
+types match the incoming data. The backend should not assume that
+returning TRUE will mean that the data will naturally follow.
+*/
+	  gboolean (*check_data_type) (const gchar *);
+
+/** Free this structure, unregister this backend handler. */
+	void (*provider_free) (QofBackendProvider *);
 };
 
 struct QofBackend_s
 {
-  void (*session_begin) (QofBackend *be,
-                         QofSession *session,
-                         const char *book_id, 
-                         gboolean ignore_lock,
-                         gboolean create_if_nonexistent);
-  void (*session_end) (QofBackend *);
-  void (*destroy_backend) (QofBackend *);
+	void (*session_begin) (QofBackend * be,
+						   QofSession * session,
+						   const gchar * book_id,
+						   gboolean ignore_lock,
+						   gboolean create_if_nonexistent);
+	void (*session_end) (QofBackend *);
+	void (*destroy_backend) (QofBackend *);
+	void (*load) (QofBackend *, QofBook *);
+	void (*begin) (QofBackend *, QofInstance *);
+	void (*commit) (QofBackend *, QofInstance *);
+	void (*rollback) (QofBackend *, QofInstance *);
+	  gpointer (*compile_query) (QofBackend *, QofQuery *);
+	void (*free_query) (QofBackend *, gpointer);
+	void (*run_query) (QofBackend *, gpointer);
+	void (*sync) (QofBackend *, QofBook *);
+	void (*load_config) (QofBackend *, KvpFrame *);
+	KvpFrame *(*get_config) (QofBackend *);
+	  gint64 (*counter) (QofBackend *, const gchar * counter_name);
+	  gboolean (*events_pending) (QofBackend *);
+	  gboolean (*process_events) (QofBackend *);
+	QofBePercentageFunc percentage;
+	QofBackendProvider *provider;
 
-  void (*load) (QofBackend *, QofBook *);
+/** Detect if the sync operation will overwrite data
 
-  void (*begin) (QofBackend *, QofInstance *);
-  void (*commit) (QofBackend *, QofInstance *);
-  void (*rollback) (QofBackend *, QofInstance *);
+File based backends tend to consider the original file
+as 'stale' immediately the data finishes loading. New data
+only exists in memory and the data in the file is completely
+replaced when qof_session_save is called. e.g. this routine can be
+used to detect if a Save As... operation would overwrite a
+possibly unrelated file. Not all file backends use this function.
 
-  gpointer (*compile_query) (QofBackend *, QofQuery *);
-  void (*free_query) (QofBackend *, gpointer);
-  void (*run_query) (QofBackend *, gpointer);
+@return TRUE if the user may need to be warned about possible
+data loss, otherwise FALSE.
+*/
+	gboolean (*save_may_clobber_data) (QofBackend *);
 
-  void (*sync) (QofBackend *, QofBook *);
-  void (*load_config) (QofBackend *, KvpFrame *);
-  KvpFrame* (*get_config) (QofBackend *);
-  gint64 (*counter) (QofBackend *, const char *counter_name);
+	QofBackendError last_err;
+	gchar *error_msg;
 
-  gboolean (*events_pending) (QofBackend *);
-  gboolean (*process_events) (QofBackend *);
+	KvpFrame *backend_configuration;
+	gint config_count;
+/** Each backend resolves a fully-qualified file path.
+This holds the filepath and communicates it to the frontends.
+*/
+	gchar *fullpath;
 
-  QofBePercentageFunc percentage;
-  
-  QofBackendProvider *provider;
+/** \deprecated */
+	void (*price_lookup) (QofBackend *, gpointer);
 
-  /** Detect if the sync operation will overwrite data
-   *
-   * File based backends tend to consider the original file
-   * as 'stale' immediately the data finishes loading. New data
-   * only exists in memory and the data in the file is completely
-   * replaced when qof_session_save is called. e.g. this routine can be
-   * used to detect if a Save As... operation would overwrite a
-   * possibly unrelated file. Not all file backends use this function.
-   *
-   * @return TRUE if the user may need to be warned about possible
-   * data loss, otherwise FALSE.
-   */
-  gboolean (*save_may_clobber_data) (QofBackend *);
-
-  QofBackendError last_err;
-  char * error_msg;
-
-  KvpFrame* backend_configuration;
-  gint config_count;
-  /** Each backend resolves a fully-qualified file path.
-   * This holds the filepath and communicates it to the frontends.
-   */
-  char * fullpath;
-
-  /** \deprecated price_lookup should be removed during the redesign
-   * of the SQL backend... prices can now be queried using
-   * the generic query mechanism.
-   *
-   * Note the correct signature for this call is 
-   * void (*price_lookup) (QofBackend *, GNCPriceLookup *);
-   * we use gpointer to avoid an unwanted include file dependency. 
-   */
-  void (*price_lookup) (QofBackend *, gpointer);
-
-  /** \deprecated Export should really _NOT_ be here, but is left here for now.
-   * I'm not sure where this should be going to. It should be
-   * removed ASAP.   This is a temporary hack-around until period-closing
-   * is fully implemented.
-   */
-  void (*export) (QofBackend *, QofBook *);
+/** \deprecated */
+	void (*export) (QofBackend *, QofBook *);
 
 };
 
-/** Let the sytem know about a new provider of backends.  This function
- *  is typically called by the provider library at library load time.
- *  This function allows the backend library to tell the QOF infrastructure
- *  that it can handle URL's of a certain type.  Note that a single
- *  backend library may register more than one provider, if it is
- *  capable of handling more than one URL access method.
- */
+/** Let the sytem know about a new provider of backends.  This
+function is typically called by the provider library at library
+load time. This function allows the backend library to tell
+QOF infrastructure that it can handle URL's of a certain type.
+Note that a single backend library may register more than one
+provider, if it is capable of handling more than one URL access
+method. */
 void qof_backend_register_provider (QofBackendProvider *);
 
-/** The qof_backend_set_error() routine pushes an error code onto the error
- *  stack. (FIXME: the stack is 1 deep in current implementation).
- */
-void qof_backend_set_error (QofBackend *be, QofBackendError err);
+/** The qof_backend_set_error() routine pushes an error code onto
+the error stack. (FIXME: the stack is 1 deep in current
+implementation). */
+void qof_backend_set_error (QofBackend * be, QofBackendError err);
 
 /** The qof_backend_get_error() routine pops an error code off the error stack.
  */
-QofBackendError qof_backend_get_error (QofBackend *be);
+QofBackendError qof_backend_get_error (QofBackend * be);
 
-/** The qof_backend_set_message() assigns a string to the backend error message.
- */
-void qof_backend_set_message(QofBackend *be, const char *format, ...);
+/** The qof_backend_set_message() assigns a string to the backend
+error message. */
+void qof_backend_set_message (QofBackend * be, const gchar * format, ...);
 
 /** The qof_backend_get_message() pops the error message string from
- *  the Backend.  This string should be freed with g_free().
- */
-char * qof_backend_get_message(QofBackend *be);
+the Backend.  This string should be freed with g_free(). */
+gchar *qof_backend_get_message (QofBackend * be);
 
-void qof_backend_init(QofBackend *be);
+void qof_backend_init (QofBackend * be);
 
 /** Allow backends to see if the book is open 
 
 @return 'y' if book is open, otherwise 'n'.
 */
-gchar qof_book_get_open_marker(QofBook *book);
+gchar qof_book_get_open_marker (QofBook * book);
 
 /** get the book version
 
@@ -400,19 +380,19 @@ used for tracking multiuser updates in backends.
 @return -1 if no book exists, 0 if the book is
 new, otherwise the book version number.
 */
-gint32 qof_book_get_version (QofBook *book);
+gint32 qof_book_get_version (QofBook * book);
 
 /** get the book tag number
 
 used for kvp management in sql backends.
 */
-guint32 qof_book_get_idata (QofBook *book);
+guint32 qof_book_get_idata (QofBook * book);
 
-void qof_book_set_version (QofBook *book, gint32 version);
+void qof_book_set_version (QofBook * book, gint32 version);
 
-void qof_book_set_idata(QofBook *book, guint32 idata);
+void qof_book_set_idata (QofBook * book, guint32 idata);
 
-/* @} */
-/* @} */
-/* @} */
+/** @} */
+/** @} */
+/** @} */
 #endif /* QOF_BACKEND_P_H */
