@@ -18,9 +18,8 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
-/** @addtogroup Object
-    @{ */
 /** @addtogroup Book
+
     A QOF Book is a dataset.  It provides a single handle
     through which all the various collections of entities
     can be found.   In particular, given only the type of
@@ -40,7 +39,7 @@
 #ifndef QOF_BOOK_H
 #define QOF_BOOK_H
 
-#include "qofid.h"
+#include "qof.h"
 #include "kvp_frame.h"
 
 /** @brief Encapsulates all the information about a dataset
@@ -60,10 +59,10 @@
 })
 
 /** \brief QofBook reference */
-typedef struct _QofBook       QofBook;
+typedef struct _QofBook QofBook;
 
 /** GList of QofBook */
-typedef GList                 QofBookList;
+typedef GList QofBookList;
 
 typedef void (*QofBookFinalCB) (QofBook *, gpointer key, gpointer user_data);
 
@@ -72,18 +71,18 @@ gboolean qof_book_register (void);
 
 /** Allocate, initialise and return a new QofBook.  Books contain references
  *  to all of the top-level object containers. */
-QofBook * qof_book_new (void);
+QofBook *qof_book_new (void);
 
 /** End any editing sessions associated with book, and free all memory
     associated with it. */
-void      qof_book_destroy (QofBook *book);
+void qof_book_destroy (QofBook * book);
 
 /** Close a book to editing.
 
 It is up to the application to check this flag,
 and once marked closed, books cannnot be marked as open.
 */
-void qof_book_mark_closed (QofBook *book);
+void qof_book_mark_closed (QofBook * book);
 
 /** Return The table of entities of the given type.
  *
@@ -98,11 +97,12 @@ void qof_book_mark_closed (QofBook *book);
  *  a non-NULL value.  (Unless the system malloc failed (out of
  *  memory) in which case what happens??).
  */
-QofCollection  * qof_book_get_collection (QofBook *, QofIdType);
+QofCollection *qof_book_get_collection (QofBook *, QofIdType);
 
 /** Invoke the indicated callback on each collection in the book. */
 typedef void (*QofCollectionForeachCB) (QofCollection *, gpointer user_data);
-void qof_book_foreach_collection (QofBook *, QofCollectionForeachCB, gpointer);
+void qof_book_foreach_collection (QofBook *, QofCollectionForeachCB,
+								  gpointer);
 
 /** Return The kvp data for the book.
  *  Note that the book KVP data is persistent, and is stored/retrieved
@@ -123,20 +123,20 @@ void qof_book_foreach_collection (QofBook *, QofCollectionForeachCB, gpointer);
  *    of the book KVP are persistent (are saved and restored to file
  *    or database), whereas the data pointers exist only at runtime.
  */
-void qof_book_set_data (QofBook *book, const gchar *key, gpointer data);
+void qof_book_set_data (QofBook * book, const gchar * key, gpointer data);
 
 /** Same as qof_book_set_data(), except that the callback will be called
  *  when the book is destroyed.  The argument to the callback will be
  *  the book followed by the data pointer.
  */
-void qof_book_set_data_fin (QofBook *book, const gchar *key, gpointer data, 
-                            QofBookFinalCB);
+void qof_book_set_data_fin (QofBook * book, const gchar * key, gpointer data,
+							QofBookFinalCB);
 
 /** Retrieves arbitrary pointers to structs stored by qof_book_set_data. */
-gpointer qof_book_get_data (QofBook *book, const gchar *key);
+gpointer qof_book_get_data (QofBook * book, const gchar * key);
 
 /** Is the book shutting down? */
-gboolean qof_book_shutting_down (QofBook *book);
+gboolean qof_book_shutting_down (QofBook * book);
 
 /** qof_book_not_saved() will return TRUE if any
  *    data in the book hasn't been saved to long-term storage.
@@ -146,32 +146,28 @@ gboolean qof_book_shutting_down (QofBook *book);
  *    'dirty' flag.  Its up to the backend to periodically reset this
  *    flag, when it actually does save the data.)
  */
-gboolean qof_book_not_saved (QofBook *book);
+gboolean qof_book_not_saved (QofBook * book);
 
 /** The qof_book_mark_saved() routine marks the book as having been
  *    saved (to a file, to a database). Used by backends to mark the
  *    notsaved flag as FALSE just after loading.  Can also be used 
  *    by the frontend when the used has said to abandon any changes.
  */
-void qof_book_mark_saved(QofBook *book);
+void qof_book_mark_saved (QofBook * book);
 
 /** Call this function when you change the book kvp, to make sure the book
  * is marked 'dirty'. */
-void qof_book_kvp_changed (QofBook *book);
+void qof_book_kvp_changed (QofBook * book);
 
 /** The qof_book_equal() method returns TRUE if books are equal.
  * XXX this routine is broken, and does not currently compare data.
  */
-gboolean qof_book_equal (QofBook *book_1, QofBook *book_2);
+gboolean qof_book_equal (QofBook * book_1, QofBook * book_2);
 
 /** This will 'get and increment' the named counter for this book.
  * The return value is -1 on error or the incremented counter.
  */
-gint64 qof_book_get_counter (QofBook *book, const char *counter_name);
-
-/** deprecated */
-#define qof_book_get_guid(X) qof_entity_get_guid (QOF_ENTITY(X))
+gint64 qof_book_get_counter (QofBook * book, const gchar *counter_name);
 
+/** @} */
 #endif /* QOF_BOOK_H */
-/** @} */
-/** @} */
