@@ -22,5 +22,5 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#define QOF_LIB_DIR "/opt/garfield/qof/lib"
+#define QOF_LIB_DIR "/opt/holly/qof/lib"
 
